aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--.gitignore2
-rw-r--r--Makefile.am4
-rw-r--r--powwow-movieplay.c (renamed from movie_play.c)8
-rw-r--r--powwow.doc8
4 files changed, 11 insertions, 11 deletions
diff --git a/.gitignore b/.gitignore
index 01dbfc5..a79a089 100644
--- a/.gitignore
+++ b/.gitignore
@@ -15,7 +15,7 @@ depcomp
follow
install-sh
missing
-movie_play
muc
powwow
powwow.6
+powwow-movieplay
diff --git a/Makefile.am b/Makefile.am
index 6f362d0..3fbcafb 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -1,7 +1,7 @@
# Default help file directory
AM_CFLAGS=-DPOWWOW_DIR=\"$(pkgdatadir)\" -DPLUGIN_DIR=\"$(plugindir)\"
-bin_PROGRAMS = powwow muc movie_play
+bin_PROGRAMS = powwow muc powwow-movieplay
powwow_SOURCES = beam.c cmd.c log.c edit.c cmd2.c eval.c \
utils.c main.c tcp.c list.c map.c tty.c \
ptr.c
@@ -11,7 +11,7 @@ powwow_HEADERS = beam.h cmd.h log.h edit.h cmd2.h eval.h \
utils.h main.h tcp.h list.h map.h tty.h \
ptr.h defines.h
muc_SOURCES = muc.c
-movie_play_SOURCES = movie_play.c
+powwow_movieplay_SOURCES = powwow-movieplay.c
noinst_PROGRAMS = catrw follow
follow_SOURCES = follow.c
diff --git a/powwow.doc b/powwow.doc
index acf2740..3c8e759 100644
--- a/powwow.doc
+++ b/powwow.doc
@@ -671,11 +671,11 @@ SPECIAL COMMANDS: ALL OTHERS
This is similar to #capture, but adds timestamps to each line
received from the main MUD connection or typed from the keyboard,
to allow replay at correct speed.
- The program `movie_play' for replay is included with powwow sources.
- Usage: `movie_play <filename>'
- To convert a movie to plain ASCII, the program `movie2ascii'
+ The program `powwow-movieplay' for replay is included with powwow sources.
+ Usage: `powwow-movieplay <filename>'
+ To convert a movie to plain ASCII, the program `powwow-movie2ascii'
is included too.
- Usage: `movie2ascii <infile> <outfile>'.
+ Usage: `powwow-movie2ascii <infile> <outfile>'.
It is possible to capture in the #movie file even text that you have
_already_ received: see #setvar buffer.
diff --git a/movie_play.c b/powwow-movieplay.c
index c095137..3cddef9 100644
--- a/movie_play.c
+++ b/powwow-movieplay.c
@@ -1,5 +1,5 @@
/*
* movie_play.c -- replay powwow movies or convert them into ASCII
*
* This file is placed in the public domain.
*/
@@ -27,10 +27,10 @@ int argc; char *argv[];
char buf[4096];
int i, play = 0;
- if (strstr(argv[0], "movie_play"))
+ if (strstr(argv[0], "powwow-movieplay"))
play = 1;
- else if (!strstr(argv[0], "movie2ascii")) {
- fprintf(stderr, "Please run this program as \"movie_play\" or \"movie2ascii\"\n");
+ else if (!strstr(argv[0], "powwow-movie2ascii")) {
+ fprintf(stderr, "Please run this program as \"powwow-movieplay\" or \"powwow-movie2ascii\"\n");
return 1;
}
@@ -1,5 +1,5 @@
/*
- * movie_play.c -- replay powwow movies or convert them into ASCII
+ * powwow-movieplay.c -- replay powwow movies or convert them into ASCII
*
* This file is placed in the public domain.